You are viewing a plain text version of this content. The canonical link for it is here.
Posted to commits@subversion.apache.org by ju...@apache.org on 2011/07/01 17:19:48 UTC

svn commit: r1141962 - in /subversion/trunk/subversion: libsvn_client/client.h libsvn_wc/adm_crawler.c

Author: julianfoad
Date: Fri Jul  1 15:19:48 2011
New Revision: 1141962

URL: http://svn.apache.org/viewvc?rev=1141962&view=rev
Log:
Tweak comments.

* subversion/libsvn_client/client.h
  (svn_client__open_ra_session_internal, svn_client__harvest_committables):
    Correct a parameter name.

* subversion/libsvn_wc/adm_crawler.c
  (report_revisions_and_depths): Clarify that the specified directory is not
    reported itself, only its children are.
  (svn_wc_crawl_revisions5): Clarify a comment, removng a long-obsolete
    reference.

Modified:
    subversion/trunk/subversion/libsvn_client/client.h
    subversion/trunk/subversion/libsvn_wc/adm_crawler.c

Modified: subversion/trunk/subversion/libsvn_client/client.h
URL: http://svn.apache.org/viewvc/subversion/trunk/subversion/libsvn_client/client.h?rev=1141962&r1=1141961&r2=1141962&view=diff
==============================================================================
--- subversion/trunk/subversion/libsvn_wc/adm_crawler.c (original)
+++ subversion/trunk/subversion/libsvn_wc/adm_crawler.c Fri Jul  1 15:19:48 2011
@@ -192,12 +192,11 @@ restore_node(svn_wc__db_t *db,
 /* The recursive crawler that describes a mixed-revision working
    copy to an RA layer.  Used to initiate updates.
 
-   This is a depth-first recursive walk of DIR_ABSPATH using DB.  Look
-   at each entry and check if its revision is different than DIR_REV.
-   If so, report this fact to REPORTER.  If an entry is.  If a node has
-   a different URL than expected, report that to REPORTER.  If an
-   entry has a different depth than its parent, report that to
-   REPORTER.
+   This is a depth-first recursive walk of the children of DIR_ABSPATH
+   (not including DIR_ABSPATH itself) using DB.  Look at each node and
+   check if its revision is different than DIR_REV.  If so, report this
+   fact to REPORTER.  If a node has a different URL than expected, or
+   a different depth than its parent, report that to REPORTER.
 
    Report DIR_ABSPATH to the reporter as REPORT_RELPATH.
 
@@ -646,9 +645,8 @@ svn_wc_crawl_revisions5(svn_wc_context_t
   svn_depth_t report_depth;
   SVN_ERR_ASSERT(svn_dirent_is_absolute(local_abspath));
 
-  /* The first thing we do is get the base_rev from the working copy's
-     ROOT_DIRECTORY.  This is the first revnum that entries will be
-     compared to. */
+  /* Get the base rev, which is the first revnum that entries will be
+     compared to, and some other WC info about the target. */
   err = svn_wc__db_base_get_info(&status, &target_kind, &target_rev,
                                  &repos_relpath, &repos_root_url,
                                  NULL, NULL, NULL, NULL, &target_depth,
--- subversion/trunk/subversion/libsvn_client/client.h (original)
+++ subversion/trunk/subversion/libsvn_client/client.h Fri Jul  1 15:19:48 2011
@@ -292,7 +292,7 @@ svn_client__default_walker_error_handler
    in *CORRECTED_URL.  (This function mirrors svn_ra_open4(), which
    see, regarding the interpretation and handling of these two parameters.)
 
-   The root of the session is specified by BASE_URL and BASE_DIR.
+   The root of the session is specified by BASE_URL and BASE_DIR_ABSPATH.
 
    Additional control parameters:
 
@@ -758,7 +758,7 @@ typedef svn_error_t *(*svn_client__check
                                                      svn_revnum_t revision,
                                                      apr_pool_t *scratch_pool);
 
 /* Recursively crawl a set of working copy paths (DIR_ABSPATH + each
    item in the TARGETS array) looking for commit candidates, locking
    working copy directories as the crawl progresses.  For each
    candidate found:
@@ -758,7 +758,7 @@ typedef svn_error_t *(*svn_client__check
                                                      apr_pool_t *scratch_pool);
 
-/* Recursively crawl a set of working copy paths (DIR_ABSPATH + each
+/* Recursively crawl a set of working copy paths (BASE_DIR_ABSPATH + each
    item in the TARGETS array) looking for commit candidates, locking
    working copy directories as the crawl progresses.  For each

Modified: subversion/trunk/subversion/libsvn_wc/adm_crawler.c
URL: http://svn.apache.org/viewvc/subversion/trunk/subversion/libsvn_wc/adm_crawler.c?rev=1141962&r1=1141961&r2=1141962&view=diff
==============================================================================